@@ -5,19 +5,25 @@
 # datetime:2021-06-10 16:45
 # software: PyCharm
 from abc import ABC
+
 from protocol_helper.setting import SURVEILLANCE_SYSTEM_DOMAIN, SURVEILLANCE_SYSTEM_TOKEN
 from protocol_helper.utils.RequestBase import RequestBase
 
 
 class MonitoringCenterService(RequestBase, ABC):
-    TIMEOUT = 10
 
     def __init__(self):
+
         self.url = SURVEILLANCE_SYSTEM_DOMAIN
         self.token = SURVEILLANCE_SYSTEM_TOKEN
-        self._headers = {
-            'Authorization': f'Token {self.token}'
-        }
+
+        if self.token is None:
+            self._headers = {}
+        else:
+            self._headers = {
+                    'Authorization': f'Token {self.token}'
+            }
+        self.HEADERS = self._headers
 
     def support_service(self):
         """
@@ -25,7 +31,7 @@ class MonitoringCenterService(RequestBase, ABC):
         Returns:
 
         """
-        return self.get(f"{self.url}/api/collection", timeout=self.TIMEOUT).json()
+        return self.get(f"{self.url}/api/collection").json()
 
     def collection(self, mode, server_type, url):
         """
@@ -39,11 +45,11 @@ class MonitoringCenterService(RequestBase, ABC):
 
         """
         data = {
-            'mode': mode,
-            'server_type': server_type,
-            'url': url
+                'mode':        mode,
+                'server_type': server_type,
+                'url':         url
         }
-        return self.post(f"{self.url}/api/collection", data=data, timeout=self.TIMEOUT).json()
+        return self.post(f"{self.url}/api/collection", data = data).json()
 
     def available_agents(self):
         """
@@ -52,7 +58,7 @@ class MonitoringCenterService(RequestBase, ABC):
 
         """
 
-        return self.get(f"{self.url}/api/agent/", timeout=self.TIMEOUT, headers=self._headers).json()
+        return self.get(f"{self.url}/api/agent/").json()
 
     def agent_status_notify(self, server_name, status):
         """
@@ -65,10 +71,10 @@ class MonitoringCenterService(RequestBase, ABC):
 
         """
         data = {
-            'status': status,
-            'server_name': server_name,
+                'status':      status,
+                'server_name': server_name,
         }
-        return self.post(f"{self.url}/api/agent/", data=data, timeout=self.TIMEOUT, headers=self._headers).json()
+        return self.post(f"{self.url}/api/agent/", data = data).json()
 
     def get_proxy_configuration(self, server_name):
         """
@@ -80,9 +86,9 @@ class MonitoringCenterService(RequestBase, ABC):
 
         """
 
-        return self.get(f"{self.url}/api/agent/{server_name}", timeout=self.TIMEOUT, headers=self._headers).json()
+        return self.get(f"{self.url}/api/agent/{server_name}").json()
 
-    def agent_lock(self, server_name, lock=0):
+    def agent_lock(self, server_name, lock = 0):
         """
         设置代理服务器加锁
         Args:
@@ -93,10 +99,9 @@ class MonitoringCenterService(RequestBase, ABC):
 
         """
         data = {
-            'status': lock
+                'status': lock
         }
-        return self.post(f"{self.url}/api/agent/{server_name}", data=data, timeout=self.TIMEOUT,
-                         headers=self._headers).json()
+        return self.post(f"{self.url}/api/agent/{server_name}", data = data).json()
 
     def get_equipment_pool(self, equipment_type):
         """
@@ -107,8 +112,7 @@ class MonitoringCenterService(RequestBase, ABC):
         Returns:
 
         """
-        return self.get(f"{self.url}/api/equipment-pool/{equipment_type}", timeout=self.TIMEOUT,
-                        headers=self._headers).json()
+        return self.get(f"{self.url}/api/equipment-pool/{equipment_type}").json()
 
     def set_equipment_pool(self, equipment_type, _hash, status):
         """
@@ -122,11 +126,10 @@ class MonitoringCenterService(RequestBase, ABC):
 
         """
         data = {
-            'hash': hash,
-            'status': status
+                'hash':   hash,
+                'status': status
         }
-        return self.post(f"{self.url}/api/equipment-pool/{equipment_type}", timeout=self.TIMEOUT, data=data,
-                         headers=self._headers).json()
+        return self.post(f"{self.url}/api/equipment-pool/{equipment_type}", data = data).json()
 
     def get_weibo_s(self, uid):
         """
@@ -139,9 +142,9 @@ class MonitoringCenterService(RequestBase, ABC):
 
         """
         data = {
-            'uid': uid,
+                'uid': uid,
         }
-        return self.get(f"{self.url}/api/wb/get-s/", timeout=self.TIMEOUT, params=data, headers=self._headers).json()
+        return self.get(f"{self.url}/api/wb/get-s/", params = data).json()
 
     def get_weibo_registered_equipment(self):
         """
@@ -149,4 +152,10 @@ class MonitoringCenterService(RequestBase, ABC):
         Returns:
 
         """
-        return self.get(f"{self.url}/api/wb/registered-equipment", timeout=self.TIMEOUT, headers=self._headers).json()
+        return self.get(f"{self.url}/api/wb/registered-equipment").json()
+
+    def get_dy_sign(self,url,uid):
+        return self.post("http://django.oa.douwangkeji.com/inside/douyin/signature", data = {
+            'url': url,
+            'uid': uid
+        },headers={})
