@@ -4,7 +4,7 @@
 # email:LeisureMam@gmail.com
 # datetime:2021-06-11 16:00
 # software: PyCharm
-from protocol_helper.Exceptions import RequestExceptions
+from protocol_helper.Exceptions import *
 
 
 class RequestBase(object):
@@ -42,7 +42,7 @@ class RequestBase(object):
 
         return kwargs
 
-    def post(self, url, data=None, json=None, **kwargs):
+    def post(self, url, data = None, json = None, **kwargs):
         """
 
         Args:
@@ -55,12 +55,12 @@ class RequestBase(object):
 
         """
         kwargs = self.__upload_request(**kwargs)
-        resp = self.requests.post(url, data=data, json=json, **kwargs)
+        resp = self.requests.post(url, data = data, json = json, **kwargs)
         if resp.status_code != 200:
-            raise RequestExceptions(resp.status_code, "Request an abnormal response", resp.text, resp)
+            raise RequestException(resp)
         return resp
 
-    def get(self, url, params=None, **kwargs):
+    def get(self, url, params = None, **kwargs):
         """
 
         Args:
@@ -73,7 +73,14 @@ class RequestBase(object):
         """
         kwargs = self.__upload_request(**kwargs)
         kwargs.setdefault('allow_redirects', True)
-        resp = self.requests.get(url, params=params, **kwargs)
+
+        resp = self.requests.get(url, params = params, **kwargs)
+        if resp.status_code in [418]:
+            raise WeiBoRequestIPLimit(resp)
+
+        if resp.status_code in [427]:
+            raise WeiBoRequestTouristClosed(resp)
+
         if resp.status_code != 200:
-            raise RequestExceptions(resp.status_code, "Request an abnormal response", resp.text, resp)
+            raise RequestException(resp)
         return resp
